- [ ] Review the sessions
	- [ ] Propose
		- [ ] Propose explore
		- [ ] Propose exploit
	- [ ] Implement
	- [ ] Test
	- [ ] Evaluate
- [ ] Consider additional experiment types
- [ ] How do runs work? Can we allow param sweeps?
- [ ] Analysis as part of eval. Can you do REPL / EDA and try to figure things out?
- [ ] What about a memory system.

---

The idea here is that node expansion in the tree of experiments is the most critical task. This is a search problem. 

---

# Logging

- [ ] Are checkpoints saved?
- [ ] Are all experiments in the user view?
- [ ] Is their sufficient context?
- [ ] Similar over mehotdsa nad findings search after you find something
- [ ] Backlog and backlog hygeine
- [ ] Automated review
- [ ] Talk to results and explore?


- Feedback and notes shold be part of it for when i review
- Are all experiments in the history presesnted ieach tim (user prompt for propose session?) 
	- Isn't it part of configruation? Can we view and edit it?
	- "Do not explore the filesystem or read files to understand abreka. All the context you need is above. Just analyze and create the experiment."
		- Is this actually sufficient?
- [ ] Wandb/lightniing/artifacts?
- [ ] Bootstrap within a coding agent command
- [ ] Research mode
- [ ] Refine mode
- [ ] Review mode


# UI changes

In the file view for an experiment in the webui,
- do not show .*__pycache__/.*
- for file names, on mouseover, show the full name (some are hidden with "...")


----

# Applications

- If you do auto search, what is the relationship between test (final) and val? Can you use this for more meta research programming
- RL on successful tree exploration?




---


- Is there no cli tool to get the method and files? I Thought there was. Couldn't the agent call taht if it know how?
- tag injection kinda makes sense?
- common crawl videos

----

- Gemma 4 hackathon
	- https://www.kaggle.com/competitions/gemma-4-good-hackathon
- Normal hackathons
	- https://www.kaggle.com/competitions

---

Experiment 1 on explore ignored backlog